@@ -1,4 +1,4 @@
-get_predictions_multinom <- function(model, fitfram, ci.lvl, linv, typical, terms, model.class, ...) {
+get_predictions_multinom <- function(model, fitfram, ci.lvl, linv, value_adjustment, terms, model_class, ...) {
 
   # compute ci, two-ways
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
@@ -26,17 +26,17 @@ get_predictions_multinom <- function(model, fitfram, ci.lvl, linv, typical, term
 
 
   # se.pred <-
-  #   .get_se_from_vcov(
+  #   .standard_error_predictions(
   #     model = model,
-  #     fitfram = fitfram,
-  #     typical = typical,
+  #     prediction_data = fitfram,
+  #     value_adjustment = value_adjustment,
   #     terms = terms,
-  #     model.class = model.class
+  #     model_class = model_class
   #   )
   #
   # if (!is.null(se.pred)) {
   #   se.fit <- se.pred$se.fit
-  #   fitfram <- se.pred$fitfram
+  #   fitfram <- se.pred$prediction_data
   #   # CI
   #   fitfram$conf.low <- linv(stats::qlogis(fitfram$predicted) - stats::qnorm(ci) * se.fit)
   #   fitfram$conf.high <- linv(stats::qlogis(fitfram$predicted) + stats::qnorm(ci) * se.fit)
