@@ -1,38 +1,105 @@
-#' @importFrom dplyr group_by summarize ungroup left_join slice filter
-#' @importFrom rlang syms .data
 #' @importFrom stats quantile sd
-get_zeroinfl_fitfram <- function(fitfram, newdata, prdat, sims, ci, clean_terms) {
+.join_simulations <- function(prediction_data, newdata, prdat, sims, ci, clean_terms) {
   # after "bootstrapping" confidence intervals by simulating from the
   # multivariate normal distribution, we need to prepare the data and
   # calculate "bootstrapped" estimates and CIs.
 
-  fitfram$sort__id <- 1:nrow(fitfram)
-  column_matches <- sapply(colnames(fitfram), function(.x) any(unique(fitfram[[.x]]) %in% newdata[[.x]]))
-  join_by <- colnames(fitfram)[column_matches]
-  fitfram <- suppressMessages(suppressWarnings(dplyr::left_join(newdata, fitfram, by = join_by)))
+  prediction_data$sort__id <- 1:nrow(prediction_data)
+  column_matches <- sapply(colnames(prediction_data), function(.x) any(unique(prediction_data[[.x]]) %in% newdata[[.x]]))
 
-  fitfram$predicted <- apply(sims, 1, mean)
-  fitfram$conf.low <- apply(sims, 1, stats::quantile, probs = 1 - ci)
-  fitfram$conf.high <- apply(sims, 1, stats::quantile, probs = ci)
-  fitfram$std.error <- apply(sims, 1, stats::sd)
+  # we need two data grids here: one for all combination of levels from the
+  # model predictors ("newdata"), and one with the current combinations only
+  # for the terms in question ("prediction_data"). "sims" has always the same
+  # number of rows as "newdata", but "prediction_data" might be shorter. So we
+  # merge "prediction_data" and "newdata", add mean and quantiles from "sims"
+  # as new variables, and then later only keep the original observations
+  # from "prediction_data" - by this, we avoid unequal row-lengths.
 
-  # group_by() changes the order of rows / variables in "fitfram", however
+  join_by <- colnames(prediction_data)[column_matches]
+  prediction_data <- merge(newdata, prediction_data, by = join_by, all = TRUE, sort = FALSE)
+
+  prediction_data$predicted <- apply(sims, 1, mean)
+  prediction_data$conf.low <- apply(sims, 1, stats::quantile, probs = 1 - ci)
+  prediction_data$conf.high <- apply(sims, 1, stats::quantile, probs = ci)
+  prediction_data$std.error <- apply(sims, 1, stats::sd)
+
+  # group_by() changes the order of rows / variables in "prediction_data", however
   # we later add back the original predictions "prdat" (see below), which
-  # correspond to the *current* sorting of fitfram. So we add a dummy-ID,
-  # which we use to restore the original sorting of fitfram later...
+  # correspond to the *current* sorting of prediction_data. So we add a dummy-ID,
+  # which we use to restore the original sorting of prediction_data later...
 
-  grp <- rlang::syms(clean_terms)
-  fitfram <- fitfram %>%
-    dplyr::filter(!is.na(.data$sort__id)) %>%
-    dplyr::group_by(!!! grp) %>%
-    dplyr::summarize(
-      predicted = mean(.data$predicted),
-      conf.low = mean(.data$conf.low),
-      conf.high = mean(.data$conf.high),
-      std.error = mean(.data$std.error),
-      id = .data$sort__id
-    ) %>%
-    dplyr::ungroup()
+
+  # The following code is a replace for dplyr, when grouping and
+  # summarizing data. previous code was:
+  #
+  # grp <- rlang::syms(clean_terms)
+  # prediction_data <- prediction_data %>%
+  #   dplyr::filter(!is.na(.data$sort__id)) %>%
+  #   dplyr::group_by(!!! grp) %>%
+  #   dplyr::summarize(
+  #     predicted = mean(.data$predicted),
+  #     conf.low = mean(.data$conf.low),
+  #     conf.high = mean(.data$conf.high),
+  #     std.error = mean(.data$std.error),
+  #     id = .data$sort__id
+  #   ) %>%
+  #   dplyr::ungroup()
+  #
+  # New code is a bit longer, but reduces pkg dependencies...
+
+  prediction_data <- prediction_data[!is.na(prediction_data$sort__id), ]
+
+  means_predicted <- tapply(
+    prediction_data$predicted,
+    lapply(clean_terms, function(i) prediction_data[[i]]),
+    function(j) mean(j, na.rm = TRUE),
+    simplify = FALSE
+  )
+
+  means_conf_low <- tapply(
+    prediction_data$conf.low,
+    lapply(clean_terms, function(i) prediction_data[[i]]),
+    function(j) mean(j, na.rm = TRUE),
+    simplify = FALSE
+  )
+
+  means_conf_high <- tapply(
+    prediction_data$conf.high,
+    lapply(clean_terms, function(i) prediction_data[[i]]),
+    function(j) mean(j, na.rm = TRUE),
+    simplify = FALSE
+  )
+
+  means_se <- tapply(
+    prediction_data$std.error,
+    lapply(clean_terms, function(i) prediction_data[[i]]),
+    function(j) mean(j, na.rm = TRUE),
+    simplify = FALSE
+  )
+
+  terms_df <- data.frame(expand.grid(attributes(means_predicted)$dimnames), stringsAsFactors = FALSE)
+  colnames(terms_df) <- clean_terms
+  terms_df <- .convert_numeric_factors(terms_df)
+
+  prediction_data <- cbind(
+    terms_df,
+    predicted = unlist(lapply(means_predicted, function(i) if (is.null(i)) NA else i)),
+    conf.low = unlist(lapply(means_conf_low, function(i) if (is.null(i)) NA else i)),
+    conf.high = unlist(lapply(means_conf_high, function(i) if (is.null(i)) NA else i)),
+    std.error = unlist(lapply(means_se, function(i) if (is.null(i)) NA else i)),
+    id = prediction_data$sort__id
+  )
+  rownames(prediction_data) <- NULL
+
+  if (length(clean_terms) == 1) {
+    prediction_data <- prediction_data[order(prediction_data[[1]]), ]
+  } else if (length(clean_terms) == 2) {
+    prediction_data <- prediction_data[order(prediction_data[[1]], prediction_data[[2]]), ]
+  } else if (length(clean_terms) == 3) {
+    prediction_data <- prediction_data[order(prediction_data[[1]], prediction_data[[2]], prediction_data[[3]]), ]
+  } else if (length(clean_terms) == 4) {
+    prediction_data <- prediction_data[order(prediction_data[[1]], prediction_data[[2]], prediction_data[[3]], prediction_data[[4]]), ]
+  }
 
   # we use the predicted values from "predict(type = "reponse")", but the
   # bootstrapped CI - so we need to fix a bit here. "predict(type = "reponse")"
@@ -42,32 +109,56 @@ get_zeroinfl_fitfram <- function(fitfram, newdata, prdat, sims, ci, clean_terms)
   # in order to make CI and predictions match, we take the simulated CI-range
   # and use the original predicted values as "center" for those CI-ranges.
 
-  if (length(prdat) == nrow(fitfram)) {
-    fitfram <- fitfram[order(fitfram$id), ]
-    ci.range <- (fitfram$conf.high - fitfram$conf.low) / 2
-    fitfram$predicted <- prdat
+  if (length(prdat) == nrow(prediction_data)) {
+    prediction_data <- prediction_data[order(prediction_data$id), ]
+    ci.range <- (prediction_data$conf.high - prediction_data$conf.low) / 2
+    prediction_data$predicted <- prdat
 
     # fix negative CI
-    ci.low <- fitfram$predicted - ci.range
+    ci.low <- prediction_data$predicted - ci.range
     neg.ci <- ci.low < 0
     if (any(neg.ci)) {
       ci.range[neg.ci] <- ci.range[neg.ci] - abs(ci.low[neg.ci]) - 1e-05
-      fitfram$std.error[neg.ci] <- fitfram$std.error[neg.ci] - ((abs(ci.low[neg.ci]) + 1e-05) / stats::qnorm(ci))
+      prediction_data$std.error[neg.ci] <- prediction_data$std.error[neg.ci] - ((abs(ci.low[neg.ci]) + 1e-05) / stats::qnorm(ci))
     }
 
-    fitfram$conf.low <- fitfram$predicted - ci.range
-    fitfram$conf.high <- fitfram$predicted + ci.range
-    fitfram <- .remove_column(fitfram, "id")
+    prediction_data$conf.low <- prediction_data$predicted - ci.range
+    prediction_data$conf.high <- prediction_data$predicted + ci.range
+    prediction_data <- .remove_column(prediction_data, "id")
   }
 
-  fitfram
+  prediction_data
 }
 
 
+
+
+.simulate_predictions <- function(model, newdata, nsim = 1000, terms = NULL, value_adjustment = NULL, condition = NULL) {
+
+  # Since the zero inflation and the conditional model are working in "opposite
+  # directions", confidence intervals can not be derived directly  from the
+  # "predict()"-function. Thus, confidence intervals for type = "fe.zi" are
+  # based on quantiles of simulated draws from a multivariate normal distribution
+  # (see also _Brooks et al. 2017, pp.391-392_ for details).
+
+  if (inherits(model, "glmmTMB")) {
+    .simulate_predictions_glmmTMB(model, newdata, nsim, terms, value_adjustment, condition)
+  } else if (inherits(model, "MixMod")) {
+    .simulate_predictions_MixMod(model, newdata, nsim, terms, value_adjustment, condition)
+  } else {
+    .simulate_predictions_zeroinfl(model, newdata, nsim, terms, value_adjustment, condition)
+  }
+}
+
+
+
+
+
+
 #' @importFrom MASS mvrnorm
 #' @importFrom stats model.matrix formula
-#' @importFrom sjmisc is_empty
-get_glmmTMB_predictions <- function(model, newdata, nsim, terms = NULL, typical = NULL, condition = NULL) {
+#' @importFrom insight get_varcov
+.simulate_predictions_glmmTMB <- function(model, newdata, nsim, terms = NULL, value_adjustment = NULL, condition = NULL) {
 
   if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("You need to install package `lme4` first to compute marginal effects.", call. = FALSE)
@@ -90,7 +181,7 @@ get_glmmTMB_predictions <- function(model, newdata, nsim, terms = NULL, typical
       # re-build the newdata-argument by including all values for poly-terms, if
       # these are hold constant.
 
-      fixes <- get_rows_to_keep(model, newdata, condformula, ziformula, terms, typical, condition)
+      fixes <- .rows_to_keep(model, newdata, condformula, ziformula, terms, value_adjustment, condition)
 
       if (!is.null(fixes)) {
         keep <- fixes$keep
@@ -105,15 +196,15 @@ get_glmmTMB_predictions <- function(model, newdata, nsim, terms = NULL, typical
       x.zi <- stats::model.matrix(ziformula, newdata)
       beta.zi <- lme4::fixef(model)$zi
 
-      cond.varcov <- getVarCov(model, component = "cond", type = "glmmTMB")
-      zi.varcov <- getVarCov(model, component = "zi", type = "glmmTMB")
+      cond.varcov <- insight::get_varcov(model, component = "conditional")
+      zi.varcov <- insight::get_varcov(model, component = "zero_inflated")
 
       pred.condpar.psim <- MASS::mvrnorm(n = nsim, mu = beta.cond, Sigma = cond.varcov)
       pred.cond.psim <- x.cond %*% t(pred.condpar.psim)
       pred.zipar.psim <- MASS::mvrnorm(n = nsim, mu = beta.zi, Sigma = zi.varcov)
       pred.zi.psim <- x.zi %*% t(pred.zipar.psim)
 
-      if (!sjmisc::is_empty(keep)) {
+      if (!.is_empty(keep)) {
         pred.cond.psim <- pred.cond.psim[keep, ]
         pred.zi.psim <- pred.zi.psim[keep, ]
       }
@@ -129,7 +220,7 @@ get_glmmTMB_predictions <- function(model, newdata, nsim, terms = NULL, typical
 
 #' @importFrom MASS mvrnorm
 #' @importFrom stats model.matrix formula
-get_MixMod_predictions <- function(model, newdata, nsim, terms = NULL, typical = NULL, condition = NULL) {
+.simulate_predictions_MixMod <- function(model, newdata, nsim, terms = NULL, value_adjustment = NULL, condition = NULL) {
 
   if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("You need to install package `lme4` first to compute marginal effects.", call. = FALSE)
@@ -145,7 +236,7 @@ get_MixMod_predictions <- function(model, newdata, nsim, terms = NULL, typical =
       # re-build the newdata-argument by including all values for poly-terms, if
       # these are hold constant.
 
-      fixes <- get_rows_to_keep(model, newdata, condformula, ziformula, terms, typical, condition)
+      fixes <- .rows_to_keep(model, newdata, condformula, ziformula, terms, value_adjustment, condition)
 
       if (!is.null(fixes)) {
         keep <- fixes$keep
@@ -160,15 +251,15 @@ get_MixMod_predictions <- function(model, newdata, nsim, terms = NULL, typical =
       x.zi <- stats::model.matrix(ziformula, newdata)
       beta.zi <- lme4::fixef(model, sub_model = "zero_part")
 
-      cond.varcov <- getVarCov(model, component = "fixed-effects", type = "MixMod")
-      zi.varcov <- getVarCov(model, component = "zero_part", type = "MixMod")
+      cond.varcov <- insight::get_varcov(model, component = "conditional")
+      zi.varcov <- insight::get_varcov(model, component = "zero_inflated")
 
       pred.condpar.psim <- MASS::mvrnorm(n = nsim, mu = beta.cond, Sigma = cond.varcov)
       pred.cond.psim <- x.cond %*% t(pred.condpar.psim)
       pred.zipar.psim <- MASS::mvrnorm(n = nsim, mu = beta.zi, Sigma = zi.varcov)
       pred.zi.psim <- x.zi %*% t(pred.zipar.psim)
 
-      if (!sjmisc::is_empty(keep)) {
+      if (!.is_empty(keep)) {
         pred.cond.psim <- pred.cond.psim[keep, ]
         pred.zi.psim <- pred.zi.psim[keep, ]
       }
@@ -184,7 +275,7 @@ get_MixMod_predictions <- function(model, newdata, nsim, terms = NULL, typical =
 
 #' @importFrom stats model.matrix coef formula as.formula
 #' @importFrom MASS mvrnorm
-get_zeroinfl_predictions <- function(model, newdata, nsim = 1000, terms = NULL, typical = NULL, condition = NULL) {
+.simulate_predictions_zeroinfl <- function(model, newdata, nsim = 1000, terms = NULL, value_adjustment = NULL, condition = NULL) {
   tryCatch(
     {
       condformula <- stats::as.formula(paste0("~", .safe_deparse(stats::formula(model)[[3]][[2]])))
@@ -195,7 +286,7 @@ get_zeroinfl_predictions <- function(model, newdata, nsim = 1000, terms = NULL,
       # re-build the newdata-argument by including all values for poly-terms, if
       # these are hold constant.
 
-      fixes <- get_rows_to_keep(model, newdata, condformula, ziformula, terms, typical, condition)
+      fixes <- .rows_to_keep(model, newdata, condformula, ziformula, terms, value_adjustment, condition)
 
       if (!is.null(fixes)) {
         keep <- fixes$keep
@@ -210,8 +301,8 @@ get_zeroinfl_predictions <- function(model, newdata, nsim = 1000, terms = NULL,
       x.zi <- stats::model.matrix(ziformula, model = "zero", data = newdata)
       beta.zi <- stats::coef(model, model = "zero")
 
-      cond.varcov <- getVarCov(model, component = "count", type = "pscl")
-      zi.varcov <- getVarCov(model, component = "zero", type = "pscl")
+      cond.varcov <- insight::get_varcov(model, component = "conditional")
+      zi.varcov <- insight::get_varcov(model, component = "zero_inflated")
 
       pred.condpar.psim <- MASS::mvrnorm(nsim, mu = beta.cond, Sigma = cond.varcov)
       pred.cond.psim <- x.cond %*% t(pred.condpar.psim)
@@ -219,7 +310,7 @@ get_zeroinfl_predictions <- function(model, newdata, nsim = 1000, terms = NULL,
       pred.zipar.psim <- MASS::mvrnorm(nsim, mu = beta.zi, Sigma = zi.varcov)
       pred.zi.psim <- x.zi %*% t(pred.zipar.psim)
 
-      if (!sjmisc::is_empty(keep)) {
+      if (!.is_empty(keep)) {
         pred.cond.psim <- pred.cond.psim[keep, ]
         pred.zi.psim <- pred.zi.psim[keep, ]
       }
@@ -233,67 +324,13 @@ get_zeroinfl_predictions <- function(model, newdata, nsim = 1000, terms = NULL,
 }
 
 
-#' @importFrom stats vcov
-getVarCov <- function(model, component, type = "glmmTMB") {
-  # sometimes, the variance-covariance matrix (needed for Sigma in MASS::mvrnorm)
-  # is negative, so MASS::mvrnorm fails. Here we check for a negativ matrix,
-  # and if it is, we try to find the nearest positive matrix.
-
-  vc <- tryCatch(
-    {
-      switch(
-        type,
-        glmmTMB = stats::vcov(model)[[component]],
-        pscl = stats::vcov(model, model = component),
-        MixMod = stats::vcov(model, parm = component),
-        stats::vcov(model)[[component]]
-      )
-    },
-    error = function(x) { NULL },
-    warning = function(x) { NULL },
-    finally = function(x) { NULL }
-  )
-
-  if ((is.null(vc) || is.negativ.matrix(vc)) && requireNamespace("Matrix", quietly = TRUE)) {
-    vc <- tryCatch(
-      {
-        m <- switch(
-          type,
-          glmmTMB = stats::vcov(model)[[component]],
-          pscl = stats::vcov(model, model = component),
-          MixMod = stats::vcov(model, parm = component),
-          stats::vcov(model)[[component]]
-        )
-
-        as.matrix(Matrix::nearPD(m)$mat)
-      },
-      error = function(x) { NULL },
-      warning = function(x) { NULL },
-      finally = function(x) { NULL }
-    )
-  }
-
-  vc
-}
 
 
-is.negativ.matrix <- function(x) {
-  if (is.matrix(x) && (nrow(x) == ncol(x))) {
-    eigenvalues <- eigen(x, only.values = TRUE)$values
-    eigenvalues[abs(eigenvalues) < 1e-07] <- 0
-    rv <- any(eigenvalues <= 0)
-  } else {
-    rv <- FALSE
-  }
-
-  rv
-}
 
 
 #' @importFrom insight get_data
-#' @importFrom sjmisc typical_value
 #' @importFrom stats quantile
-get_rows_to_keep <- function(model, newdata, condformula, ziformula, terms, typical, condition) {
+.rows_to_keep <- function(model, newdata, condformula, ziformula, terms, value_adjustment, condition) {
   # if formula has a polynomial term, and this term is one that is held
   # constant, model.matrix() with "newdata" will throw an error - so we
   # re-build the newdata-argument by including all values for poly-terms, if
@@ -307,7 +344,7 @@ get_rows_to_keep <- function(model, newdata, condformula, ziformula, terms, typi
 
   if (.has_poly_term(condformula_string) || .has_poly_term(ziformula_string)) {
 
-    mf <- insight::get_data(model)
+    model_frame <- insight::get_data(model)
 
     polycondcheck <- NULL
     polyzicheck <- NULL
@@ -318,7 +355,7 @@ get_rows_to_keep <- function(model, newdata, condformula, ziformula, terms, typi
         polycondcheck <- polyterm
         polydg <- .get_poly_degree(condformula_string)
         polyvals <- paste0(
-          stats::quantile(mf[[polyterm]], probs = seq_len(polydg + 1) / (polydg + 2)),
+          stats::quantile(model_frame[[polyterm]], probs = seq_len(polydg + 1) / (polydg + 2)),
           collapse = ","
         )
         terms <- c(terms, sprintf("%s [%s]", polyterm, polyvals))
@@ -331,20 +368,20 @@ get_rows_to_keep <- function(model, newdata, condformula, ziformula, terms, typi
         polyzicheck <- polyterm
         polydg <- .get_poly_degree(ziformula_string)
         polyvals <- paste0(
-          stats::quantile(mf[[polyterm]], probs = seq_len(polydg + 1) / (polydg + 2)),
+          stats::quantile(model_frame[[polyterm]], probs = seq_len(polydg + 1) / (polydg + 2)),
           collapse = ","
         )
         terms <- c(terms, sprintf("%s [%s]", polyterm, polyvals))
       }
     }
 
-    newdata <- .get_data_grid(
+    newdata <- .data_grid(
       model = model,
-      mf = mf,
+      model_frame = model_frame,
       terms = terms,
-      typ.fun = typical,
-      fac.typical = FALSE,
-      pretty.message = FALSE,
+      value_adjustment = value_adjustment,
+      factor_adjustment = FALSE,
+      show_pretty_message = FALSE,
       condition = condition
     )
 
@@ -353,25 +390,25 @@ get_rows_to_keep <- function(model, newdata, condformula, ziformula, terms, typi
 
     if (!is.null(polycondcheck)) {
       keep.cond <- lapply(polycondcheck, function(.x) {
-        wm <- newdata[[.x]][which.min(abs(newdata[[.x]] - sjmisc::typical_value(newdata[[.x]], fun = typical)))]
+        wm <- newdata[[.x]][which.min(abs(newdata[[.x]] - .typical_value(newdata[[.x]], fun = value_adjustment)))]
         as.vector(which(newdata[[.x]] == wm))
       }) %>% unlist()
     }
 
     if (!is.null(polyzicheck)) {
       keep.zi <- lapply(polyzicheck, function(.x) {
-        wm <- newdata[[.x]][which.min(abs(newdata[[.x]] - sjmisc::typical_value(newdata[[.x]], fun = typical)))]
+        wm <- newdata[[.x]][which.min(abs(newdata[[.x]] - .typical_value(newdata[[.x]], fun = value_adjustment)))]
         as.vector(which(newdata[[.x]] == wm))
       }) %>% unlist()
     }
 
     keep <- intersect(keep.cond, keep.zi)
 
-    if (sjmisc::is_empty(keep))
+    if (.is_empty(keep))
       keep <- unique(c(keep.cond, keep.zi))
   }
 
-  if (sjmisc::is_empty(keep)) return(NULL)
+  if (.is_empty(keep)) return(NULL)
 
   list(keep = keep, newdata = newdata)
 }
