@@ -1,18 +1,18 @@
 # add labels to grouping and facet variables, if these
 # variables come from labelled data
-#' @importFrom sjmisc recode_to is_num_fac
+#' @importFrom sjmisc recode_to
 #' @importFrom sjlabelled get_labels set_labels
 #' @importFrom stats na.omit
-.add_labels_to_groupvariable <- function(mydf, ori.mf, terms) {
+.add_labels_to_groupvariable <- function(mydf, original_model_frame, terms) {
   grp.lbl <- sjlabelled::get_labels(
-    ori.mf[[terms[2]]],
+    original_model_frame[[terms[2]]],
     non.labelled = TRUE,
     values = "n",
     drop.unused = TRUE
   )
 
   # no new labels for labelled factors
-  if (is.factor(mydf$group) && !sjmisc::is_num_fac(mydf$group))
+  if (is.factor(mydf$group) && !.is_numeric_factor(mydf$group))
     grp.lbl <- NULL
 
   # drop levels, if necessary
@@ -35,14 +35,14 @@
 
   if (.obj_has_name(mydf, "facet")) {
     facet.lbl <- sjlabelled::get_labels(
-      ori.mf[[terms[3]]],
+      original_model_frame[[terms[3]]],
       non.labelled = TRUE,
       values = "n",
       drop.unused = TRUE
     )
 
     # no new labels for labelled factors
-    if (is.factor(mydf$facet) && !sjmisc::is_num_fac(mydf$facet))
+    if (is.factor(mydf$facet) && !.is_numeric_factor(mydf$facet))
       facet.lbl <- NULL
 
     # drop levels, if necessary
@@ -98,24 +98,24 @@
 
 # get labels from labelled data for axis titles and labels
 #' @importFrom sjlabelled get_label
-.get_axis_titles_and_labels <- function(fitfram, terms, fun, faminfo, no.transform, type) {
+.get_axis_titles_and_labels <- function(original_model_frame, terms, fun, model_info, no.transform, type) {
   # Retrieve response for automatic title
-  resp.col <- colnames(fitfram)[1]
+  resp.col <- colnames(original_model_frame)[1]
 
   # check for family, and set appropriate scale-title
   # if we have transformation through effects-package,
   # check if data is on original or transformed scale
-  ysc <- get_title_labels(fun, faminfo, no.transform, type)
+  ysc <- get_title_labels(fun, model_info, no.transform, type)
 
   # set plot-title
   t.title <-
     paste(sprintf("Predicted %s of", ysc),
-          sjlabelled::get_label(fitfram[[1]], def.value = resp.col))
+          sjlabelled::get_label(original_model_frame[[1]], def.value = resp.col))
 
 
   # axis titles
-  x.title <- sjlabelled::get_label(fitfram[[terms[1]]], def.value = terms[1])
-  y.title <- sjlabelled::get_label(fitfram[[1]], def.value = resp.col)
+  x.title <- sjlabelled::get_label(original_model_frame[[terms[1]]], def.value = terms[1])
+  y.title <- sjlabelled::get_label(original_model_frame[[1]], def.value = resp.col)
 
 
   if (fun == "coxph") {
@@ -131,12 +131,12 @@
 
 
   # legend title
-  l.title <- sjlabelled::get_label(fitfram[[terms[2]]], def.value = terms[2])
+  l.title <- sjlabelled::get_label(original_model_frame[[terms[2]]], def.value = terms[2])
 
   # check if we have a categorical variable with value
   # labels at the x-axis.
   axis.labels <- sjlabelled::get_labels(
-    fitfram[[terms[1]]],
+    original_model_frame[[terms[1]]],
     non.labelled = TRUE,
     drop.unused = TRUE
   )
@@ -151,17 +151,17 @@
 }
 
 
-get_title_labels <- function(fun, faminfo, no.transform, type) {
+get_title_labels <- function(fun, model_info, no.transform, type) {
   ysc <- "values"
 
   if (fun == "glm") {
-    if (faminfo$is_brms_trial)
+    if (model_info$is_brms_trial)
       ysc <- "successes"
-    else if (faminfo$is_binomial || faminfo$is_ordinal)
+    else if (model_info$is_binomial || model_info$is_ordinal)
       ysc <- ifelse(isTRUE(no.transform), "log-odds", "probabilities")
-    else if (faminfo$is_count)
+    else if (model_info$is_count)
       ysc <- ifelse(isTRUE(no.transform), "log-mean", "counts")
-  } else if (faminfo$is_beta) {
+  } else if (model_info$is_beta) {
     ysc <- "proportion"
   } else if (fun == "coxph") {
     if (!is.null(type) && type == "surv")
