@@ -21,8 +21,10 @@ get_predict_function <- function(model) {
   if (inherits(model, c("wblm", "wbm"))) return("wbm")
   else if (inherits(model, "glimML")) return("glimML")
   else if (inherits(model, "ols")) return("ols")
+  else if (inherits(model, "glmx")) return("glmx")
   else if (inherits(model, "lrm")) return("lrm")
   else if (inherits(model, "lmrob")) return("lmrob")
+  else if (inherits(model, "feglm")) return("feglm")
   else if (inherits(model, "glmrob")) return("glmrob")
   else if (inherits(model, "glmRob")) return("glmRob")
   else if (inherits(model, "brglm")) return("glm")
@@ -48,6 +50,7 @@ get_predict_function <- function(model) {
   else if (inherits(model, "lme")) return("lme")
   else if (inherits(model, "logistf")) return("logistf")
   else if (inherits(model, "ivreg")) return("ivreg")
+  else if (inherits(model, "fixest")) return("fixest")
   else if (inherits(model, "gls")) return("gls")
   else if (inherits(model, "geeglm")) return("geeglm")
   else if (inherits(model, "clmm")) return("clmm")
